==> visual-third-party-0.1.6-hana-1qpay-sources.jar: com/tenqube/visual_third/util/Mapper.java <==
package com.tenqube.visual_third.util;

import com.tenqube.visual_third.exception.ParameterException;
import com.tenqube.visual_third.model.analysis.Analysis;
import com.tenqube.visual_third.model.api.SearchCompanyRequest;
import com.tenqube.visual_third.entity.Card;
import com.tenqube.visual_third.entity.Category;
import com.tenqube.visual_third.entity.JoinedTransaction;
import com.tenqube.visual_third.entity.UserCategory;
import com.tenqube.visual_third.model.api.TransactionRequest;
import com.tenqube.visual_third.model.js.Cards;
import com.tenqube.visual_third.model.js.CategoryInfo;
import com.tenqube.visual_third.model.js.Lv0Info;
import com.tenqube.visual_third.model.js.Transactions;

import java.util.ArrayList;

import tenqube.parser.model.Transaction;

public class Mapper {

    public static ArrayList<com.tenqube.visual_third.model.analysis.Transaction> toAnalysisTran(ArrayList<JoinedTransaction> transactions) {
        ArrayList<com.tenqube.visual_third.model.analysis.Transaction> trans = new ArrayList<>();

        for(JoinedTransaction transaction : transactions) {
            try {
                trans.add(new com.tenqube.visual_third.model.analysis.Transaction(transaction));
            } catch (ParameterException e) {

            }
        }

        return trans;
    }

    public static ArrayList<Lv0Info.Lv0> toLv0s(ArrayList<Analysis> analyses) {
        ArrayList<Lv0Info.Lv0> trans = new ArrayList<>();

        for(Analysis analysis : analyses) {
            try {
                trans.add(new Lv0Info.Lv0(analysis));
            } catch (ParameterException e) {

            }
        }

        return trans;
    }

    public static ArrayList<SearchCompanyRequest.Transaction> toSearchTransaction(ArrayList<com.tenqube.visual_third.model.parser.Transaction> transactions) {

        ArrayList<SearchCompanyRequest.Transaction> trans = new ArrayList<>();

        for(com.tenqube.visual_third.model.parser.Transaction transaction : transactions) {
            try {
                trans.add(new SearchCompanyRequest.Transaction(transaction.getParsedTransaction()));
            } catch (ParameterException e) {

            }
        }

        return trans;

    }

    public static ArrayList<SearchCompanyRequest.Transaction> toSearchTransactionWithEntity(ArrayList<JoinedTransaction> transactions) {

        ArrayList<SearchCompanyRequest.Transaction> trans = new ArrayList<>();

        for(JoinedTransaction transaction : transactions) {
            try {
                trans.add(new SearchCompanyRequest.Transaction(transaction));
            } catch (ParameterException e) {

            }
        }

        return trans;

    }

    public static ArrayList<com.tenqube.visual_third.model.parser.Transaction> toParserTransactions(ArrayList<Transaction> parsedTransactions) {

        ArrayList<com.tenqube.visual_third.model.parser.Transaction> results = new ArrayList<>();

        for(Transaction transaction : parsedTransactions) {
            try {
                results.add(new com.tenqube.visual_third.model.parser.Transaction(transaction));
            } catch (ParameterException e) {

            }
        }

        return results;
    }


    public static ArrayList<Transactions.Transaction> toJsTransactions(ArrayList<JoinedTransaction> transactions) {

        ArrayList<Transactions.Transaction> results = new ArrayList<>();

        for(JoinedTransaction transaction : transactions) {
            results.add(new Transactions.Transaction(transaction));
        }

        return results;
    }

    public static ArrayList<TransactionRequest.Transaction> toApiTransactions(ArrayList<JoinedTransaction> transactions) {

        ArrayList<TransactionRequest.Transaction> results = new ArrayList<>();

        for(JoinedTransaction transaction : transactions) {
            try {
                results.add(new TransactionRequest.Transaction(transaction));
            } catch (ParameterException e) {

            }
        }

        return results;
    }

    public static ArrayList<Cards.Card> toJsCards(ArrayList<Card> cards) {
        ArrayList<Cards.Card> results = new ArrayList<>();

        for(Card card : cards) {
            results.add(new Cards.Card(card));
        }

        return results;
    }

    public static ArrayList<CategoryInfo.ServerCategory> toJsCategories(ArrayList<Category> categories) {
        ArrayList<CategoryInfo.ServerCategory> results = new ArrayList<>();

        for(Category category : categories) {
            results.add(new CategoryInfo.ServerCategory(category));
        }

        return results;
    }

    public static ArrayList<CategoryInfo.UserCategory> toJsUserCategories(ArrayList<UserCategory> userCategories) {
        ArrayList<CategoryInfo.UserCategory> results = new ArrayList<>();

        for(UserCategory userCategory : userCategories) {
            results.add(new CategoryInfo.UserCategory(userCategory));
        }

        return results;
    }
}

==> visual-third-party-0.3.4-hana-1qpay-sources.jar: com/tenqube/visual_third/util/Mapper.java <==
package com.tenqube.visual_third.util;

import com.tenqube.visual_third.exception.ParameterException;
import com.tenqube.visual_third.model.analysis.Analysis;
import com.tenqube.visual_third.model.api.SearchCompanyRequest;
import com.tenqube.visual_third.entity.Card;
import com.tenqube.visual_third.entity.Category;
import com.tenqube.visual_third.entity.JoinedTransaction;
import com.tenqube.visual_third.entity.UserCategory;
import com.tenqube.visual_third.model.api.TransactionRequest;
import com.tenqube.visual_third.model.js.Cards;
import com.tenqube.visual_third.model.js.CategoryInfo;
import com.tenqube.visual_third.model.js.Lv0Info;
import com.tenqube.visual_third.model.js.Transactions;

import java.util.ArrayList;

import tenqube.parser.model.Transaction;

public class Mapper {

    public static ArrayList<com.tenqube.visual_third.model.analysis.Transaction> toAnalysisTran(ArrayList<JoinedTransaction> transactions) {
        ArrayList<com.tenqube.visual_third.model.analysis.Transaction> trans = new ArrayList<>();

        for(JoinedTransaction transaction : transactions) {
            try {
                trans.add(new com.tenqube.visual_third.model.analysis.Transaction(transaction));
            } catch (ParameterException e) {

            }
        }

        return trans;
    }

    public static ArrayList<Lv0Info.Lv0> toLv0s(ArrayList<Analysis> analyses) {
        ArrayList<Lv0Info.Lv0> trans = new ArrayList<>();

        for(Analysis analysis : analyses) {
            try {
                trans.add(new Lv0Info.Lv0(analysis));
            } catch (ParameterException e) {

            }
        }

        return trans;
    }

    public static ArrayList<SearchCompanyRequest.Transaction> toSearchTransaction(ArrayList<com.tenqube.visual_third.model.parser.Transaction> transactions) {

        ArrayList<SearchCompanyRequest.Transaction> trans = new ArrayList<>();

        for(com.tenqube.visual_third.model.parser.Transaction transaction : transactions) {
            try {
                trans.add(new SearchCompanyRequest.Transaction(transaction.getParsedTransaction()));
            } catch (ParameterException e) {

            }
        }

        return trans;

    }

    public static ArrayList<SearchCompanyRequest.Transaction> toSearchTransactionWithEntity(ArrayList<JoinedTransaction> transactions) {

        ArrayList<SearchCompanyRequest.Transaction> trans = new ArrayList<>();

        for(JoinedTransaction transaction : transactions) {
            try {
                trans.add(new SearchCompanyRequest.Transaction(transaction));
            } catch (ParameterException e) {

            }
        }

        return trans;

    }

    public static ArrayList<com.tenqube.visual_third.model.parser.Transaction> toParserTransactions(ArrayList<Transaction> parsedTransactions) {

        ArrayList<com.tenqube.visual_third.model.parser.Transaction> results = new ArrayList<>();

        for(Transaction transaction : parsedTransactions) {
            try {
                results.add(new com.tenqube.visual_third.model.parser.Transaction(transaction));
            } catch (ParameterException e) {

            }
        }

        return results;
    }


    public static ArrayList<Transactions.Transaction> toJsTransactions(ArrayList<JoinedTransaction> transactions) {

        ArrayList<Transactions.Transaction> results = new ArrayList<>();

        for(JoinedTransaction transaction : transactions) {
            results.add(new Transactions.Transaction(transaction));
        }

        return results;
    }

    public static ArrayList<TransactionRequest.Transaction> toApiTransactions(ArrayList<JoinedTransaction> transactions, String uid) {

        ArrayList<TransactionRequest.Transaction> results = new ArrayList<>();

        for(JoinedTransaction transaction : transactions) {
            try {
                results.add(new TransactionRequest.Transaction(transaction, uid));
            } catch (ParameterException e) {

            }
        }

        return results;
    }

    public static ArrayList<Cards.Card> toJsCards(ArrayList<Card> cards) {
        ArrayList<Cards.Card> results = new ArrayList<>();

        for(Card card : cards) {
            results.add(new Cards.Card(card));
        }

        return results;
    }

    public static ArrayList<CategoryInfo.ServerCategory> toJsCategories(ArrayList<Category> categories) {
        ArrayList<CategoryInfo.ServerCategory> results = new ArrayList<>();

        for(Category category : categories) {
            results.add(new CategoryInfo.ServerCategory(category));
        }

        return results;
    }

    public static ArrayList<CategoryInfo.UserCategory> toJsUserCategories(ArrayList<UserCategory> userCategories) {
        ArrayList<CategoryInfo.UserCategory> results = new ArrayList<>();

        for(UserCategory userCategory : userCategories) {
            results.add(new CategoryInfo.UserCategory(userCategory));
        }

        return results;
    }
}
